@@ -5,20 +5,21 @@ use locale;
 use POSIX;
 use Locale::gettext;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 
 sub new {
 	my $class = shift;
 	my $obj = bless { @_ }, $class;
-	setlocale(LC_MESSAGES, "");
-	textdomain('dbman');
+
+    $obj->{ gettext } = Locale::gettext->domain( 'dbman' );
 	return $obj;
 }
 
 sub str {
 	my $obj = shift;
 	my $str = join '',@_;
-	return gettext $str;
+
+	return $obj->{ gettext }->get( $str );
 }
